@@ -1,3 +1,4 @@
+from typing import Optional
 from googleapiclient import discovery
 from oauth2client.service_account import ServiceAccountCredentials
 import backoff
@@ -7,7 +8,6 @@ from googleapiclient.errors import HttpError
 from google.auth.exceptions import RefreshError
 from google.oauth2.credentials import Credentials
 
-
 class MctAccountLostAccessException(Exception):
     """Raised when we cannot access to an account."""
     pass
@@ -18,11 +18,18 @@ class MerchantCenterServiceDownException(Exception):
     pass
 
 
+def get_exception_message(merchant_id: str, access_token: Optional[str] = None) -> str:
+    if access_token:
+        return F"We cannot access your Merchant Center account with the id: {merchant_id}. Are you sure you have access and entered correct ID?"
+    else:
+        return F"We cannot access your Merchant Center account with the id: {merchant_id} from the Arcane account. Are you sure you granted access and gave the correct ID?"
+
+
 def get_mct_service(
-    adscale_key: str = None,
-    access_token: str = None,
+    adscale_key: Optional[str] = None,
+    access_token: Optional[str] = None,
     cache_discovery=True
-):
+) -> discovery.Resource:
     """ adscale_key or access_token must be specified """
 
     if access_token:
@@ -41,8 +48,8 @@ def get_mct_service(
 @backoff.on_exception(backoff.expo, (socket.timeout), max_tries=3)
 def get_mct_account_details(
     merchant_id: int,
-    adscale_key: str = None,
-    access_token: str = None
+    adscale_key: Optional[str] = None,
+    access_token: Optional[str] = None
 ):
     """
         From mct id check if user has access to it.
@@ -57,10 +64,10 @@ def get_mct_account_details(
         response_account_statuses = request_account_statuses.execute()
     # RefreshError is raised when we have invalid merchant_id or we don't have access to the account
     except RefreshError as err:
-        raise MctAccountLostAccessException(f"We cannot access your Merchant Center account with the id: {merchant_id}. Are you sure you grant access and give correct ID?")
+        raise MctAccountLostAccessException(get_exception_message(access_token, merchant_id))
     except HttpError as err:
         if err.resp.status >= 400 and err.resp.status < 500:
-            raise MctAccountLostAccessException(f"We cannot access your Merchant Center account with the id: {merchant_id}. Are you sure you grant access and give correct ID?")
+            raise MctAccountLostAccessException(get_exception_message(access_token, merchant_id))
         else:
             raise MerchantCenterServiceDownException(f"The Merchent Center API does not respond. Thus, we cannot check if we can access your Merchant Center account with the id: {merchant_id}. Please try later" )
     return response_account_statuses['name']
@@ -69,8 +76,8 @@ def get_mct_account_details(
 @backoff.on_exception(backoff.expo, (socket.timeout), max_tries=3)
 def check_if_multi_client_account(
     merchant_id: int,
-    adscale_key: str = None,
-    access_token: str = None
+    adscale_key: Optional[str] = None,
+    access_token: Optional[str] = None
 ):
     """
         Sends an error if the account is a MCA
@@ -84,7 +91,7 @@ def check_if_multi_client_account(
         response_account_statuses = request_account_products.execute()
     # RefreshError is raised when we have invalid merchant_id or we don't have access to the account
     except RefreshError as err:
-        raise MctAccountLostAccessException(f"We cannot access your Merchant Center account with the id: {merchant_id}. Are you sure you grant access and give correct ID?")
+        raise MctAccountLostAccessException(get_exception_message(access_token, merchant_id))
     except HttpError as err:
         if err.resp.status >= 400 and err.resp.status < 500:
             raise MctAccountLostAccessException(f"This merchant id ({merchant_id} is for multi acccounts. You can only link sub-accounts.")
